@@ -2,6 +2,10 @@ import pygame
 import sys
 import threading
 import time
+import os
+
+pasta_do_projeto = os.path.dirname( os.path.abspath(__file__) )
+pasta_das_imagens = pasta_do_projeto
 
 pausado = False
 pygame.init()
@@ -82,10 +86,10 @@ tecla_numero_8 = pygame.K_KP8
 tecla_numero_9 = pygame.K_KP9
 
 #setas
-tecla_seta_esquerda = pygame.K_LEFT
-tecla_seta_direita = pygame.K_RIGHT
-tecla_seta_cima = pygame.K_UP
-tecla_seta_baixo = pygame.K_DOWN
+tecla_seta_para_esquerda = pygame.K_LEFT
+tecla_seta_para_direita = pygame.K_RIGHT
+tecla_seta_para_cima = pygame.K_UP
+tecla_seta_para_baixo = pygame.K_DOWN
 
 #teclas especiais
 tecla_espaco = pygame.K_SPACE
@@ -125,13 +129,22 @@ direcao_nula = [0,0]
 #Deve ser passada uma imagem para que o objeto seja criado
 #Demais características devem ser alteradas após a criação do objeto
 class Objeto():
-    def __init__(self, nome_da_imagem = ''):
+    def __init__(self, nome_da_imagem = 'galinha'):
         #Para threading do objeto quando apagado
         self._existe = True
-        #define área da imagem e imagem
-        self.imagem = pygame.image.load(nome_da_imagem)
+        #define imagem
+        self.nome_da_imagem = nome_da_imagem
+        if( '.' not in self.nome_da_imagem ):
+            self.nome_da_imagem += '.png'
+            self.nome_da_imagem = os.path.join( pasta_das_imagens, self.nome_da_imagem)
+        self.imagem = pygame.image.load(self.nome_da_imagem)
+        
+        #define área da imagem
         self.area_da_imagem = self.imagem.get_rect()
 
+        #usado quando o tamanho da imagem é alterado
+        self.manter_proporção = True
+
         #A velocidade define a taxa com que o objeto se move na tela
         #Pode ser lida como pixels por segundo
         self.velocidade = 100
@@ -267,8 +280,8 @@ class Objeto():
         return self.area_da_imagem.width
 
     @largura.setter
-    def largura(self, largura, manter_proporção= True):
-        if(manter_proporção == True):
+    def largura(self, largura):
+        if(self.manter_proporção ):
             altura = int( self.altura*largura/self.largura)
             self.imagem= pygame.transform.scale( self.imagem,
                                                  [largura, altura] )
@@ -285,11 +298,16 @@ class Objeto():
 
     @altura.setter
     def altura(self, altura):
-        largura = int( self.largura*altura/self.altura)
-        self.imagem= pygame.transform.scale( self.imagem, [largura, altura] )
-        self.area_da_imagem.width = largura
-        self.area_da_imagem.height = altura
-                
+        if( self.manter_proporção ):
+            largura = int( self.largura*altura/self.altura)
+            self.imagem= pygame.transform.scale( self.imagem, [largura, altura] )
+            self.area_da_imagem.width = largura
+            self.area_da_imagem.height = altura
+        else:
+            self.imagem= pygame.transform.scale( self.imagem,
+                                                 [self.largura, altura] )
+            self.area_da_imagem.height = altura
+                    
     #mostra posição do objeto
     @property
     def posicao(self):
